@@ -19,7 +19,7 @@
  *
  * This file contains functions for interfacing with the GDB remote protocol.
  *
- * $Id: jtag.h,v 1.29 2008/09/29 20:52:20 joerg_wunsch Exp $
+ * $Id: jtag.h,v 1.30 2011/08/30 13:40:32 joerg_wunsch Exp $
  */
 
 #ifndef JTAG_H
@@ -28,6 +28,7 @@
 #include <sys/types.h>
 #include <termios.h>
 
+#include "pragma.h"
 #include "ioreg.h"
 
 /* The data in this structure will be sent directorly to the jtagice box. */
@@ -581,8 +582,8 @@ typedef struct {
 // into this struct, then pass the entire struct to the target writer.
 typedef struct {
     AVRMemoryByte image[MAX_IMAGE_SIZE];
-    int last_address;
-    int first_address;
+    unsigned int last_address;
+    unsigned int first_address;
     bool first_address_ok;
     bool has_data;
     const char *name;
