@@ -18,7 +18,7 @@
  *
  * This file extends the generic "jtag" class for the mkII protocol.
  *
- * $Id: jtag2.h,v 1.16 2008/09/29 20:52:20 joerg_wunsch Exp $
+ * $Id: jtag2.h,v 1.17 2011/08/30 13:40:32 joerg_wunsch Exp $
  */
 
 #ifndef JTAG2_H
@@ -152,7 +152,7 @@ class jtag2: public jtag
 	useDebugWire = useDW;
 	apply_nSRST = nsrst;
         is_xmega = xmega;
-	flashCachePageAddr = (unsigned long)-1;
+	flashCachePageAddr = (unsigned int)-1;
 	eepromCachePageAddr = (unsigned short)-1;
 	for (int i = 0; i < MAX_BREAKPOINTS2; i++)
 	  softBPcache[i].type = NONE;
