@@ -23,7 +23,7 @@
  * This file implements the target memory programming interface for
  * the mkII protocol.
  *
- * $Id: jtag2prog.cc,v 1.3 2006/08/08 21:27:34 joerg_wunsch Exp $
+ * $Id: jtag2prog.cc,v 1.6 2011/08/30 13:51:27 joerg_wunsch Exp $
  */
 
 
@@ -112,7 +112,6 @@ void jtag2::eraseProgramPage(unsigned long address)
 static int check_file_format(bfd *file)
 {
     char **matching;
-    int done = 0;
     int err = 1;
 
     // Check if archive, not plain file.
@@ -158,7 +157,6 @@ static int check_file_format(bfd *file)
 static unsigned int get_section_addr(asection *section, BFDmemoryType memtype)
 {
     BFDmemoryType sectmemtype;
-    unsigned int addr = section->lma;
 
     if ((section->flags & SEC_HAS_CONTENTS) &&
         ((section->flags & SEC_ALLOC) || (section->flags & SEC_LOAD)))
@@ -169,6 +167,8 @@ static unsigned int get_section_addr(asection *section, BFDmemoryType memtype)
             sectmemtype = MEM_RAM;
         else if (section->lma < FUSE_SPACE_ADDR_OFFSET) // < 0x82...
             sectmemtype = MEM_EEPROM;
+        else			// e.g. .fuses
+	    return 0xffffff;
 
 	if (memtype == sectmemtype) {
             if (sectmemtype == MEM_FLASH) {
@@ -246,8 +246,8 @@ void jtag2::downloadToTarget(const char* filename, bool program, bool verify)
     // Basically, we just open the file and copy blocks over to the JTAG
     // box.
     struct stat ifstat;
-    char *target = NULL;
-    char *default_target = "binary";
+    const char *target = NULL;
+    const char *default_target = "binary";
     unsigned int page_size;
     bool done = 0;
     bfd *file;
