@@ -22,7 +22,7 @@
  *
  * This file contains functions for interfacing with the JTAG box.
  *
- * $Id: jtagprog.cc,v 1.17 2008/07/29 18:44:57 joerg_wunsch Exp $
+ * $Id: jtagprog.cc,v 1.19 2011/08/30 13:51:27 joerg_wunsch Exp $
  */
 
 
@@ -105,7 +105,6 @@ void jtag1::eraseProgramPage(unsigned long address)
 static int check_file_format(bfd *file)
 {
     char **matching;
-    int done = 0;
     int err = 1;
 
     // Check if archive, not plain file.
@@ -151,7 +150,6 @@ static int check_file_format(bfd *file)
 static unsigned int get_section_addr(asection *section, BFDmemoryType memtype)
 {
     BFDmemoryType sectmemtype;
-    unsigned int addr = section->lma;
 
     if ((section->flags & SEC_HAS_CONTENTS) && 
         ((section->flags & SEC_ALLOC) || (section->flags & SEC_LOAD)))
@@ -162,7 +160,9 @@ static unsigned int get_section_addr(asection *section, BFDmemoryType memtype)
             sectmemtype = MEM_RAM;
         else if (section->lma < FUSE_SPACE_ADDR_OFFSET) // < 0x82...
             sectmemtype = MEM_EEPROM;
-        
+        else			// e.g. .fuses
+	    return 0xffffff;
+
         if (memtype == sectmemtype) {
             if (sectmemtype == MEM_FLASH) {
                 /* Don't mask the lma or you will not be able to handle more
